==> qcad-3.32.4.0-2-x86_64.pkg.tar.zst: usr/lib/qcad/ts/qcadgui_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation type="unfinished">Vertikálne/horizontálne</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation type="unfinished">Späť</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation>Vlastné</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation>Mriežka</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Koniec</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>Na prvku</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>Kolmica</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>Dotyčnica</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Stred</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Stred</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Prienik</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Odkaz</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation type="unfinished">Vzdialenosť</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation>Neplatné</translation>
    </message>
</context>
</TS>

==> qcad-3.32.4.4-3-x86_64.pkg.tar.zst: usr/lib/qcad/ts/qcadgui_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation>Vertikálne/horizontálne</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation>Späť</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation>Vlastné</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation>Mriežka</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Koniec</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>Na prvku</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>Kolmica</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>Dotyčnica</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Stred</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Stred</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Prienik</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Odkaz</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation>Vzdialenosť</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation>Neplatné</translation>
    </message>
</context>
</TS>
